==> igniteui-webcomponents-layouts-4.3.2.tgz: package/esm5/lib/igc-tool-action-icon-button-component.js <==
import { __extends } from "tslib";
import { IgcToolActionComponent } from "./igc-tool-action-component";
import { ToolActionIconButton } from "./ToolActionIconButton";
import { getAllPropertyNames, toSpinal } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
var IgcToolActionIconButtonComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgcToolActionIconButtonComponent, _super);
    function IgcToolActionIconButtonComponent() {
        return _super.call(this) || this;
    }
    IgcToolActionIconButtonComponent.prototype.createImplementation = function () {
        return new ToolActionIconButton();
    };
    Object.defineProperty(IgcToolActionIconButtonComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionIconButtonComponent.prototype.connectedCallback = function () {
        if (_super.prototype["connectedCallback"]) {
            _super.prototype["connectedCallback"].call(this);
        }
        if (this.i.connectedCallback) {
            this.i.connectedCallback();
        }
        if (!this._attached) {
            this._attached = true;
            this._flushQueuedAttributes();
        }
    };
    IgcToolActionIconButtonComponent.prototype.disconnectedCallback = function () {
        if (_super.prototype["disconnectedCallback"]) {
            _super.prototype["disconnectedCallback"].call(this);
        }
        if (this.i.disconnectedCallback) {
            this.i.disconnectedCallback();
        }
        if (this._attached) {
            this._attached = false;
        }
    };
    Object.defineProperty(IgcToolActionIconButtonComponent, "observedAttributes", {
        get: function () {
            if (IgcToolActionIconButtonComponent._observedAttributesIgcToolActionIconButtonComponent == null) {
                var names = getAllPropertyNames(IgcToolActionIconButtonComponent);
                for (var i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcToolActionIconButtonComponent._observedAttributesIgcToolActionIconButtonComponent = names;
            }
            return IgcToolActionIconButtonComponent._observedAttributesIgcToolActionIconButtonComponent;
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionIconButtonComponent.register = function () {
        if (!IgcToolActionIconButtonComponent._isElementRegistered) {
            IgcToolActionIconButtonComponent._isElementRegistered = true;
            RegisterElementHelper.registerElement(IgcToolActionIconButtonComponent.htmlTagName, IgcToolActionIconButtonComponent);
        }
    };
    Object.defineProperty(IgcToolActionIconButtonComponent.prototype, "tooltipDelay", {
        /**
         * Gets or sets how long it takes before the tooltip is displayed (in milliseconds).
        */
        get: function () {
            return this.i.fk;
        },
        set: function (v) {
            this.i.fk = +v;
            this._a("tooltipDelay", this.i.fk);
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionIconButtonComponent.prototype.cleanUp = function () {
        this.i.dd();
    };
    IgcToolActionIconButtonComponent.prototype.openSubMenu = function () {
        this.i.d2();
    };
    IgcToolActionIconButtonComponent.prototype.closeSubmenu = function () {
        this.i.df();
    };
    IgcToolActionIconButtonComponent.prototype.fromInfo = function (info) {
        this.i.dp(info);
    };
    IgcToolActionIconButtonComponent._observedAttributesIgcToolActionIconButtonComponent = null;
    IgcToolActionIconButtonComponent.htmlTagName = "igc-tool-action-icon-button";
    IgcToolActionIconButtonComponent._isElementRegistered = false;
    return IgcToolActionIconButtonComponent;
}(IgcToolActionComponent));
export { IgcToolActionIconButtonComponent };

==> igniteui-webcomponents-layouts-4.8.0.tgz: package/esm5/lib/igc-tool-action-icon-button-component.js <==
import { __extends } from "tslib";
import { IgcToolActionComponent } from "./igc-tool-action-component";
import { ToolActionIconButton } from "./ToolActionIconButton";
import { getAllPropertyNames, toSpinal } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
var IgcToolActionIconButtonComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgcToolActionIconButtonComponent, _super);
    function IgcToolActionIconButtonComponent() {
        return _super.call(this) || this;
    }
    IgcToolActionIconButtonComponent.prototype.createImplementation = function () {
        return new ToolActionIconButton();
    };
    Object.defineProperty(IgcToolActionIconButtonComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionIconButtonComponent.prototype.connectedCallback = function () {
        if (_super.prototype["connectedCallback"]) {
            _super.prototype["connectedCallback"].call(this);
        }
        if (this.i.connectedCallback) {
            this.i.connectedCallback();
        }
        if (!this._attached) {
            this._attached = true;
            this._flushQueuedAttributes();
        }
    };
    IgcToolActionIconButtonComponent.prototype.disconnectedCallback = function () {
        if (_super.prototype["disconnectedCallback"]) {
            _super.prototype["disconnectedCallback"].call(this);
        }
        if (this.i.disconnectedCallback) {
            this.i.disconnectedCallback();
        }
        if (this._attached) {
            this._attached = false;
        }
    };
    Object.defineProperty(IgcToolActionIconButtonComponent, "observedAttributes", {
        get: function () {
            if (IgcToolActionIconButtonComponent._observedAttributesIgcToolActionIconButtonComponent == null) {
                var names = getAllPropertyNames(IgcToolActionIconButtonComponent);
                for (var i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcToolActionIconButtonComponent._observedAttributesIgcToolActionIconButtonComponent = names;
            }
            return IgcToolActionIconButtonComponent._observedAttributesIgcToolActionIconButtonComponent;
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionIconButtonComponent.register = function () {
        if (!IgcToolActionIconButtonComponent._isElementRegistered) {
            IgcToolActionIconButtonComponent._isElementRegistered = true;
            RegisterElementHelper.registerElement(IgcToolActionIconButtonComponent.htmlTagName, IgcToolActionIconButtonComponent);
        }
    };
    Object.defineProperty(IgcToolActionIconButtonComponent.prototype, "tooltipDelay", {
        /**
         * Gets or sets how long it takes before the tooltip is displayed (in milliseconds).
        */
        get: function () {
            return this.i.fo;
        },
        set: function (v) {
            this.i.fo = +v;
            this._a("tooltipDelay", this.i.fo);
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionIconButtonComponent.prototype.cleanUp = function () {
        this.i.dh();
    };
    IgcToolActionIconButtonComponent.prototype.openSubMenu = function () {
        this.i.d6();
    };
    IgcToolActionIconButtonComponent.prototype.closeSubmenu = function () {
        this.i.dj();
    };
    IgcToolActionIconButtonComponent.prototype.fromInfo = function (info) {
        this.i.dt(info);
    };
    IgcToolActionIconButtonComponent._observedAttributesIgcToolActionIconButtonComponent = null;
    IgcToolActionIconButtonComponent.htmlTagName = "igc-tool-action-icon-button";
    IgcToolActionIconButtonComponent._isElementRegistered = false;
    return IgcToolActionIconButtonComponent;
}(IgcToolActionComponent));
export { IgcToolActionIconButtonComponent };
